@@ -71,17 +71,17 @@ def make_normal_dist( rock, sample_size, correlation=.8 ):
     r = np.matrix( np.random.randn(3,sample_size ) )
 
     # Define a covariance matrix
-    co_var = np.linalg.cholesky( np.matrix( [ [1.0,cor,cor],
-                                              [cor,1.0,cor],
-                                              [cor,cor,1.0]]))
+    co_var = np.linalg.cholesky(np.matrix([[1.0,cor,cor],
+                                           [cor,1.0,cor],
+                                           [cor,cor,1.0]]))
 
     # Apply it to the distributions to add dependence
     data = co_var * r
-    d1 = ( np.array(data[0,:].flat) ) * rock.vp_sig  + rock.vp
-    d2 = ( np.array(data[1,:].flat)) * rock.vs_sig + rock.vs
-    d3 = ( np.array( data[2,:].flat) ) * rock.rho_sig + rock.rho
+    d1 = (np.array(data[0,:].flat)) * rock.vp_sig  + rock.vp
+    d2 = (np.array(data[1,:].flat)) * rock.vs_sig + rock.vs
+    d3 = (np.array( data[2,:].flat)) * rock.rho_sig + rock.rho
 
-    return( d1,d2,d3 )
+    return (d1,d2,d3)
     
 def run_script(args): 
     
@@ -89,9 +89,9 @@ def run_script(args):
 
     args.plot_type = 'dashboard'
     Rprop0 = args.Rock0
-    print "Rprop0:", Rprop0
+
     Rprop1 = args.Rock1
-    print "Rprop1:", Rprop1
+
 
     theta = np.arange(0,90)
     
@@ -124,14 +124,15 @@ def run_script(args):
     
     for i in range( args.iterations ):
         
-        reflect.append( args.reflectivity_method( vp0[i], vs0[i], rho0[i],
-                                                  vp1[i], vs1[i], rho1[i],
-                                                  theta) )
+        reflect.append(args.reflectivity_method(vp0[i], vs0[i],
+                                                rho0[i], vp1[i],
+                                                vs1[i], rho1[i],
+                                                theta))
     reflect = np.array(reflect)
-    
+    reflect = np.nan_to_num(reflect)
     #temp = np.concatenate( (vp0, rho0, vs0, vp1, rho1, vs1,), axis=0)
     
-    temp = np.concatenate( (vp0, vs0, rho0, vp1, vs1, rho1), axis=0)
+    temp = np.concatenate((vp0, vs0, rho0, vp1, vs1, rho1), axis=0)
     
     prop_samples = np.reshape(temp, (6, args.iterations))
     ave_reflect = np.mean(reflect,axis=0)
@@ -280,17 +281,17 @@ def run_script(args):
    # Patches for the Background template AVO plot STARTS here
    #  
       
-    a1 = 0.05    # transparency for AVO background template patches
+    a1 = 0.10    # transparency for AVO background template patches
     rangex = 90  
-    band = 0.02 
+    band = 0.04  # thickness of Class 2 band
     # CLASS 1
     
     Path1 = mpath.Path
     path_data1 = [
-        (Path1.MOVETO, (rangex * 0, 0.1)),
-        (Path1.CURVE4, (rangex *0.25, 0.095)),
-        (Path1.CURVE4, (rangex *0.45, 0.085)),
-        (Path1.CURVE4, (rangex *1.0, -0.05)),
+        (Path1.MOVETO, (rangex * 0, 0.04)),
+        (Path1.CURVE4, (rangex *0.4, 0.05)),
+        (Path1.CURVE4, (rangex *0.6, -0.015)),
+        (Path1.CURVE4, (rangex *1.0, -band)),
         (Path1.LINETO, (rangex *1.0, 1.0)),
         (Path1.LINETO, (rangex *0.0, 1.0)),
         (Path1.CLOSEPOLY, (rangex *0.0, 1.0)),
@@ -308,13 +309,13 @@ def run_script(args):
     
     Path2P = mpath.Path
     path_data2P = [
-        (Path2P.MOVETO, (rangex * 0, 0.1)),
-        (Path2P.CURVE4, (rangex * 0.25, 0.095)),
-        (Path2P.CURVE4, (rangex * 0.45, 0.085)),
-        (Path2P.CURVE4, (rangex * 1.0, -0.05)),
-        (Path2P.LINETO, (rangex * 1.0, -0.1)),
-        (Path2P.CURVE4, (rangex * 0.6, -0.03)),
-        (Path2P.CURVE4, (rangex * 0.4, -0.015)),
+        (Path2P.MOVETO, (rangex * 0, band)),
+        (Path2P.CURVE4, (rangex * 0.4, 0.05)),
+        (Path2P.CURVE4, (rangex * 0.6, -0.015)),
+        (Path2P.CURVE4, (rangex * 1.0, - band)),
+        (Path2P.LINETO, (rangex * 1.0, - (band + band) )),
+        (Path2P.CURVE4, (rangex * 0.6, -(0.015 + band))),
+        (Path2P.CURVE4, (rangex * 0.4, 0.05 - band)),
         (Path2P.CURVE4, (rangex * 0.0, 0.0)),
         (Path2P.CLOSEPOLY, (rangex * 0.0, 0.0)),
         ]
@@ -332,13 +333,13 @@ def run_script(args):
     Path2 = mpath.Path
     path_data2 = [
         (Path2.MOVETO, (rangex * 0.0, 0.0)),
-        (Path2.CURVE4, (rangex * 0.4, -0.015)),
-        (Path2.CURVE4, (rangex * 0.6, -0.03)),
-        (Path2.CURVE4, (rangex * 1.0, -0.1)),
-        (Path2.LINETO, (rangex * 1.0, -0.1 - band)),
-        (Path2.CURVE4, (rangex * 0.6, -0.03 - band)),
-        (Path2.CURVE4, (rangex * 0.4, -0.015 - band)),
-        (Path2.CURVE4, (rangex * 0.0, - band - 0.01)),
+        (Path2.CURVE4, (rangex * 0.4, 0.05 - band)),
+        (Path2.CURVE4, (rangex * 0.6, -(0.015 + band))),
+        (Path2.CURVE4, (rangex * 1.0, - (band + band))),
+        (Path2.LINETO, (rangex * 1.0,  - (3 * band))),
+        (Path2.CURVE4, (rangex * 0.6, - (0.015 + 2*band))),
+        (Path2.CURVE4, (rangex * 0.4, 0.05 - (0.0 + 2*band))),
+        (Path2.CURVE4, (rangex * 0.0, - band)),
         (Path2.CLOSEPOLY, (rangex * 0.0, 0.0)),
         ]
     codes2, verts2 = zip(*path_data2)
@@ -354,10 +355,10 @@ def run_script(args):
     # CLASS 3
     Path3 = mpath.Path
     path_data3 = [
-        (Path3.MOVETO, (rangex * 0.0, - band - 0.01)),
-        (Path3.CURVE4, (rangex * 0.4, -0.015 - band)),
-        (Path3.CURVE4, (rangex * 0.6, -0.03 - band)),
-        (Path3.CURVE4, (rangex * 1.0, -0.1 - band)),
+        (Path3.MOVETO, (rangex * 0.0, - band)),
+        (Path3.CURVE4, (rangex * 0.4, 0.05 - (0.0 + 2*band))),
+        (Path3.CURVE4, (rangex * 0.6, - (0.015 + 2*band))),
+        (Path3.CURVE4, (rangex * 1.0, - (3 * band))),
         (Path3.LINETO, (rangex * 1.0, -1.0)),
         (Path3.LINETO, (rangex * 0.0, -1.0)),
         (Path3.CLOSEPOLY, (rangex * 0.0, -1.0)),
@@ -395,43 +396,44 @@ def run_script(args):
     # Class 1 label  
     
     # y-values for class labels 1,2p, 2, 3, and 4 respectively
-    ylabelcntrs = [ 0.35, 0.05, -0.05, -0.4, -0.2  ]
+    ylabelcntrs = [ 0.35, 0.025, -0.025, -0.4, -0.2  ]
     xctrs = 10
-    # fontsize for AVO curve class annotation
-    fs = 10 
-    # transparency value for Gradient vs Intercept text 
     
-    a2 = 0.3   
+    fs = 10 # fontsize 
+    
+    a2 = 0.4   # transparency value for Gradient vs Intercept text 
                 
     ax.text( xctrs, ylabelcntrs[0], 'CLASS 1',
                 verticalalignment='center',
                 horizontalalignment='left',
                 color='red', fontsize=fs, fontweight = 'bold', alpha=a2)
                 
-    # Class 2P label     
+    # Class 2p label     
     ax.text( xctrs, ylabelcntrs[1], 'CLASS 2p',
                 verticalalignment='center',
                 horizontalalignment='left',
+                rotation = -3,
                 color='#EEC900', fontsize=fs, fontweight = 'bold', alpha=a2 * 1.5)
                 
     # Class 2 label     
     ax.text( xctrs, ylabelcntrs[2], 'CLASS 2',
                 verticalalignment='center',
                 horizontalalignment='left',
+                rotation = -3,
                 color='green', fontsize=fs, fontweight = 'bold', alpha=a2)
                 
     # Class 3 label     
-    ax.text( 3 * xctrs, ylabelcntrs[3],  'CLASS 3',
+    ax.text( xctrs, ylabelcntrs[3],  'CLASS 3',
                 verticalalignment='center',
-                horizontalalignment='center',
+                horizontalalignment='left',
                 rotation = -15,
                 color='blue', fontsize=fs, fontweight = 'bold', alpha=a2)   
                 
     # Class 4 label     
-    ax.text( 2 * xctrs, ylabelcntrs[4],  'CLASS 4',
+    ax.text( xctrs, ylabelcntrs[4],  'CLASS 4',
                 verticalalignment='center',
-                horizontalalignment='center',
-                rotation = 25,
+                horizontalalignment='left',
+                rotation = 15,
                 color='#B048B5', fontsize=fs, fontweight = 'bold', alpha=a2)  
     #
     # Patches for background template AVO plot ENDS here
@@ -499,22 +501,20 @@ def run_script(args):
     
     s0 = -x
     
-    shift2 = 0.05 #width for class2 width in plot
-    
-    a = 0.05
+    shift2 = 0.04 #width for class2 width in plot
     
     height_ellipse = 0.05
     width_ellipse = 3.0
     
     # Plot background trend (diagonal line)
-    ax.plot(x, s0, color='black', alpha = a)
+    ax.plot(x, s0, color='black', alpha = a1)
     
     # add a rectangle for class 2 neg
     lowleft2 = (-shift2,-1.0)
     
     class2neg = mpatches.Rectangle( lowleft2, width = abs(lowleft2[0]), height = 1.0,
                                 color = 'green',
-                                alpha = a,
+                                alpha = a1,
                                 ec = "white",
                                 lw = 4)
     ax.add_patch(class2neg)
@@ -523,7 +523,7 @@ def run_script(args):
     lowleft2pos = (0.0, 0.0)
     class2pos = mpatches.Rectangle( lowleft2pos, width = abs(lowleft2[0]), height = 1.0,
                                 color = 'green',
-                                alpha = a,
+                                alpha = a1,
                                 ec="white",
                                 lw = 4)   
     ax.add_patch(class2pos)
@@ -532,7 +532,7 @@ def run_script(args):
     lowleft2Ppos = (-shift2, 0.0)
     class2Ppos = mpatches.Rectangle( lowleft2Ppos, width = abs(lowleft2[0]), height = 1.0,
                                 color = 'yellow',
-                                alpha = a,
+                                alpha = a1,
                                 ec="white",
                                 lw = 4)   
     ax.add_patch(class2Ppos)
@@ -541,7 +541,7 @@ def run_script(args):
     lowleft2Pneg = (0.0, -1.0)
     class2Ppos = mpatches.Rectangle( lowleft2Pneg, width = abs(lowleft2[0]), height = 1.0,
                                 color = 'yellow',
-                                alpha = a,
+                                alpha = a1,
                                 ec="white",
                                 lw = 4)   
     ax.add_patch(class2Ppos)
@@ -550,7 +550,7 @@ def run_script(args):
     lowleft3neg = (-1.0, -1.0)
     class3neg = mpatches.Rectangle(lowleft3neg, width = 1.0 + lowleft2[0], height = 1.0, 
                                     color = 'blue',
-                                    alpha = a,
+                                    alpha = a1,
                                     ec = 'none')
     ax.add_patch(class3neg)
     
@@ -558,7 +558,7 @@ def run_script(args):
     lowleft3pos = (shift2, 0)
     class3pos = mpatches.Rectangle(lowleft3pos, width = 1.0 + lowleft2[0], height = 1.0,
                                     color = 'blue',
-                                    alpha = a,
+                                    alpha = a1,
                                     ec = 'none')
     ax.add_patch(class3pos)
     
@@ -575,7 +575,7 @@ def run_script(args):
     codes4u, verts4u = zip(*path_data4u)
     path4u = mpath.Path(verts4u, codes4u)
     patch4u = mpatches.PathPatch(path4u, facecolor = '#B048B5',    # purple
-                        alpha = a,
+                        alpha = a1,
                         ec = 'none')
     ax.add_patch(patch4u)
     
@@ -592,7 +592,7 @@ def run_script(args):
     codes4l, verts4l = zip(*path_data4l)
     path4l = mpath.Path(verts4l, codes4l)
     patch4l = mpatches.PathPatch(path4l, facecolor = '#B048B5',    # purple
-                        alpha = a,
+                        alpha = a1,
                         ec = 'none')
     ax.add_patch(patch4l)
     
@@ -609,7 +609,7 @@ def run_script(args):
     codes1u, verts1u = zip(*path_data1u)
     path1u = mpath.Path(verts1u, codes1u)
     patch1u = mpatches.PathPatch(path1u, facecolor = 'red',
-                        alpha = a,
+                        alpha = a1,
                         ec = 'none')
     ax.add_patch(patch1u)
     
@@ -624,7 +624,7 @@ def run_script(args):
     codes1l, verts1l = zip(*path_data1l)
     path1l = mpath.Path(verts1l, codes1l)
     patch1l = mpatches.PathPatch(path1l, facecolor = 'red',
-                        alpha = a,
+                        alpha = a1,
                         ec = 'none')
     ax.add_patch(patch1l)
     
@@ -655,14 +655,9 @@ def run_script(args):
     ax.spines['left'].set_position(('data',0))
     ax.spines['left'].set_alpha(0.5)
     
-    # Annotation 
+    # Annotation for Gradient vs Intercept annotation
     
-    # fontsize for Gradient vs Intercept annotation
-    fs = 10 
-    # transparency value for Gradient vs Intercept text 
-    a2 = 0.3   
-    
-    ax.text(0.98, 0.98, 'Gradient vs Intercept',
+    ax.text(0.98, 0.98, 'Gradient vs intercept',
             verticalalignment='top',
             horizontalalignment='right',
             transform=ax.transAxes,
@@ -705,11 +700,14 @@ def run_script(args):
                 horizontalalignment='right',
                 color='#B048B5', fontsize=fs, fontweight = 'bold', alpha=a2)
                 
-    # Background label     
+    # Background label  
+    angle = -45
+          
     ax.text( 0.1 * height_ellipse, 0.1 * height_ellipse, 'background',
                 verticalalignment='center',
                 horizontalalignment='center',
-                rotation = -45,
+                rotation = angle,
+                transform=ax.transData,
                 color='black', fontsize=fs, fontweight = 'bold', alpha=a2/2.0)
                               
     return get_figure_data()
