@@ -37,7 +37,9 @@ def get_figure_data(transparent=False):
     #image_file.close()
     return data
 
-def wiggle(data, dt=1, line_colour='black', fill_colour='blue',
+
+def wiggle(data, tstart,dt=1, line_colour='black',
+           fill_colour='blue',
            opacity= 0.5, skipt=0, gain=1, lwidth=.5, xax=1,
            quadrant=plt):
     """
@@ -51,27 +53,31 @@ def wiggle(data, dt=1, line_colour='black', fill_colour='blue',
     :param xax: scaler of axis to match image plot
     """  
   
-    t = np.arange(data.shape[0])*dt
+
+    t = (np.arange(data.shape[0]) * dt * 1000) + tstart
+
+    # Need to resample this time axis to the same size as data.shape[1]
+
     for i in range(0,data.shape[1],skipt+1):
 
         trace = data[:,i]
         
-        trace[0]=0
-        trace[-1]=0 
-        new_trace = gain*(trace/np.amax(data))
-
-        scaler = (np.amax(xax)-np.amin(xax))/float( len(xax))
+        trace[0]=0      # make trace start at zero
+        trace[-1]=0     # make trace end at zero
         
+        new_trace = gain*(trace/np.amax(data))   # gain
+
+        scaler = (np.amax(xax)-np.amin(xax))/float( len(xax)) # scale for window     
         
         quadrant.plot( (i + new_trace) * scaler + min(xax), t, color=line_colour, 
-                  linewidth=lwidth,alpha=opacity)
+                  linewidth = lwidth, alpha = opacity)
                 
         quadrant.fill_betweenx(t, ((i + new_trace) * scaler)+min(xax), (i * scaler)+min(xax) ,  new_trace > 0,
                          color=fill_colour, alpha=opacity, lw=0)
                 
         quadrant.axis('tight')
 
-def modelr_plot( model, colourmap, args ):
+def modelr_plot(model, colourmap, args):
     """
 Calculates reflectivities from the earth model then convolves
 against a bank of wavelets. Figures of various slices are created
@@ -89,8 +95,13 @@ model to physical rock properties.
     model_aspect = float(model.shape[1]) / model.shape[0]
 
     if not hasattr(args, 'xscale'):
-        args.xscale=0
+        args.xscale = 0
     
+    if not hasattr(args, "twt_range"):
+        args.twt_range = (0, model.shape[0] * dt * 1000.0)
+    
+    if not hasattr(args, 'fs'):
+        args.fs = 10
     
     if args.slice == 'spatial':
         traces = range( args.ntraces )
@@ -136,8 +147,11 @@ model to physical rock properties.
         f = args.f
 
 
+    tstart = args.twt_range[0]
+    fs = int(args.fs)
+     
     model = model[:, traces, :]
-    model = np.reshape( model, (model.shape[0], np.size(traces),3) )
+    model = np.reshape(model, (model.shape[0], np.size(traces),3))
 
     
     ############################
@@ -269,14 +283,16 @@ model to physical rock properties.
             # Now find out what sort of plot we're making on this
             # loop...
             if layer == 'earth-model':
-                axarr[0, p].imshow(model,
+                axarr[0, p].imshow(model.astype('uint8'),
                           cmap = plt.get_cmap('gist_earth'),
                           vmin = np.amin(model)-np.amax(model)/2,
                           vmax = np.amax(model)+np.amax(model)/2,
                           alpha = alpha,
                           aspect='auto',
                           extent=[min(xax),max(xax),
-                                   plot_data.shape[0]*dt,0],
+                                   args.twt_range[1],
+                                   args.twt_range[0]
+                                 ],
                           origin = 'upper'
                            )
             
@@ -293,7 +309,9 @@ model to physical rock properties.
                            alpha = alpha,
                            aspect='auto',
                            extent=[min(xax),max(xax),
-                                   plot_data.shape[0]*dt,0],
+                                   args.twt_range[1],
+                                   args.twt_range[0]
+                                   ],
                            origin = 'upper'
                            )
                 
@@ -310,18 +328,20 @@ model to physical rock properties.
                            cmap = plt.get_cmap('Greys'),
                            aspect='auto',
                            extent=[min(xax),max(xax),
-                                   plot_data.shape[0]*dt,0],
+                                   args.twt_range[1], args.twt_range[0]
+                                   ],
                            origin = 'upper' ,
                            vmin = np.amin( masked_refl ),
                            vmax = np.amax( masked_refl )
                            )
 
             elif layer == 'wiggle':
-            # wiggle needs an alpha setting too
+                
                 wigdata=plot_data
                 if wigdata.ndim == 3:
                     wigdata= np.sum(plot_data,axis=-1)
-                wiggle(wigdata,
+                wiggle(wigdata, 
+                       tstart = int(args.twt_range[0]),
                        dt = dt,
                        skipt = args.wiggle_skips,
                        gain = args.wiggle_skips + 1,
@@ -352,20 +372,27 @@ model to physical rock properties.
                            alpha = alpha,
                            aspect='auto',
                            extent=[min(xax),max(xax),
-                                   envelope.shape[0]*dt,0],
+                                   args.twt_range[1], args.twt_range[0]
+                                   ],
                            origin = 'upper'
                            )
             else:
                 # We should never get here
                 continue
              
-        axarr[0, p].set_xlabel(xlabel)
-        axarr[0, p].set_ylabel('time [s]')
-        axarr[0, p].set_title(args.title % locals())
+        axarr[0, p].set_xlabel(xlabel, fontsize=fs)
+        axarr[0, p].set_ylabel('time [ms]', fontsize=fs)
+        axarr[0, p].set_title(args.title % locals(), fontsize=fs )
+        
+        for tick in axarr[0,p].xaxis.get_major_ticks():
+            tick.label.set_fontsize(fs) 
+        
+        for tick in axarr[0,p].yaxis.get_major_ticks():
+            tick.label.set_fontsize(fs) 
         
         #plot inst. amplitude at 150 ms (every 6 samples, we should parameterize)
         t = args.tslice
-        t_index = np.amin([int(t*1000.0), plot_data.shape[0]-1])
+        t_index = int(np.amin([t, plot_data.shape[0]-1]))
         y = plot_data[t_index,:].flatten()
         
         
@@ -379,7 +406,7 @@ model to physical rock properties.
         axarr[1,p].plot(xax[:],y,'ko-',lw=3,alpha=0.2, color = 'g')
         if args.xscale: #check for log plot on graphs too
             axarr[1, p].set_xscale('log', basex = int(args.xscale) )
-        axarr[1,p].set_xlabel(xlabel)
+        axarr[1,p].set_xlabel(xlabel, fontsize=fs)
         
         # horizontal line, plot min, plot max
         axarr[1, p].axhline(y=amin_tune, alpha=0.15, lw=3, color = 'g')
@@ -403,9 +430,18 @@ model to physical rock properties.
         except:
             pass
         #labels
-        axarr[1, p].set_title('instantaneous attribute at %s ms' % int(t*1000.0))
-        axarr[1, p].set_ylabel('amplitude')
+        axarr[1, p].set_title('instantaneous attribute at %s ms' % int(t),
+                               fontsize=fs
+                              )
+        axarr[1, p].set_ylabel('amplitude', fontsize=fs)
         axarr[1,p].grid()
+        
+        for tick in axarr[1,p].xaxis.get_major_ticks():
+            tick.label.set_fontsize(fs) 
+        
+        for tick in axarr[1,p].yaxis.get_major_ticks():
+            tick.label.set_fontsize(fs)
+             
         plt.xlim((xax[0], xax[-1]))
         
         #plot horizontal green line on model image, and steady state
@@ -549,14 +585,15 @@ def multi_plot(model, reflectivity, seismic, traces,
             # loop...        
             if layer == 'earth-model':
                 
-                axarr[0, p].imshow(model,
-                          cmap = plt.get_cmap('brg'),
-                          vmin = np.amin(model)-np.amax(model)/2,
-                          vmax = np.amax(model)+np.amax(model)/2,
+                axarr[0, p].imshow(model.astype('int'),
+                          #cmap = plt.get_cmap('gist_earth'),
+                          #vmin = np.amin(model)-np.amax(model)/2,
+                          #vmax = np.amax(model)+np.amax(model)/2,
                           alpha = alpha,
                           aspect='auto',
                           extent=[min(xax),max(xax),
-                                   plot_data.shape[0]*dt,0],
+                                   args.twt_range[1], args.twt_range[0]
+                                   ],
                           origin = 'upper'  
                            )
             
@@ -581,7 +618,7 @@ def multi_plot(model, reflectivity, seismic, traces,
                            alpha = alpha,
                            aspect='auto',
                            extent=[min(xax),max(xax),
-                                   plot_data.shape[0]*dt,0], 
+                                   args.twt_range[1], args.twt_range[0]], 
                            origin = 'upper'
                            )         
                                               
@@ -605,7 +642,8 @@ def multi_plot(model, reflectivity, seismic, traces,
                            cmap = plt.get_cmap('Greys'),
                            aspect='auto',
                            extent=[min(xax),max(xax),
-                                   plot_data.shape[0]*dt,0],
+                                   args.twt_range[1], args.twt_range[0]
+                                   ],
                            origin = 'upper' ,
                            vmin = np.amin( masked_refl ),
                            vmax = np.amax( masked_refl )
@@ -616,7 +654,8 @@ def multi_plot(model, reflectivity, seismic, traces,
                 wigdata=plot_data
                 if wigdata.ndim == 3:
                     wigdata= np.sum(plot_data,axis=-1)
-                wiggle(wigdata,
+                wiggle(wigdata, 
+                       tstart = int(args.twt_range[0]), 
                        dt = dt,
                        skipt = args.wiggle_skips,
                        gain = args.wiggle_skips + 1,
@@ -647,21 +686,27 @@ def multi_plot(model, reflectivity, seismic, traces,
                            alpha = alpha,
                            aspect='auto',
                            extent=[min(xax),max(xax),
-                                   envelope.shape[0]*dt,0], 
+                                   args.twt_range[1], args.twt_range[0]
+                                   ], 
                            origin = 'upper'
                            )
             else:
                 # We should never get here
                 continue   
             
-        axarr[0, p].set_xlabel(xlabel)
-        axarr[0, p].set_ylabel('time [s]')
-        axarr[0, p].set_title(args.title % locals())
-
+        axarr[0, p].set_xlabel(xlabel, fontsize=fs)
+        axarr[0, p].set_ylabel('time [ms]', fontsize=fs)
+        axarr[0, p].set_title(args.title % locals(), fontsize=fs)
         
+        for tick in axarr[0,p].xaxis.get_major_ticks():
+            tick.label.set_fontsize(fs) 
+        
+        for tick in axarr[0,p].yaxis.get_major_ticks():
+            tick.label.set_fontsize(fs) 
+                
         #plot inst. amplitude at 150 ms (every 6 samples, we should parameterize)
         t = args.tslice
-        t_index = np.amin([int(t*1000.0), plot_data.shape[0]-1])
+        t_index = int(np.amin([t, plot_data.shape[0]-1]))
         y = plot_data[t_index,:].flatten()
         
         
@@ -676,7 +721,7 @@ def multi_plot(model, reflectivity, seismic, traces,
         if args.xscale and args.slice=="frequency":    #check for log plot on graphs too
             if args.xscale=='octave':
                 axarr[1, p].set_xscale('log', basex=2)
-        axarr[1,p].set_xlabel(xlabel)
+        axarr[1,p].set_xlabel(xlabel, fontsize=fs)
         
         # horizontal line, plot min, plot max
         axarr[1, p].axhline(y=amin_tune, alpha=0.15, lw=3, color = 'g')
@@ -699,11 +744,19 @@ def multi_plot(model, reflectivity, seismic, traces,
         except:
             pass
         #labels
-        axarr[1, p].set_title('instantaneous attribute at %s ms' % int(t*1000.0))
-        axarr[1, p].set_ylabel('amplitude')
+        axarr[1, p].set_title('instantaneous attribute at %s ms' % int(t*1000.0),
+                               fontsize=fs
+                               )
+        axarr[1, p].set_ylabel('amplitude', fs )
         axarr[1,p].grid()
         axarr[1,p].set_xlim(xax[0], xax[-1])
         
+        for tick in axarr[1,p].xaxis.get_major_ticks():
+            tick.label.set_fontsize(fs) 
+        
+        for tick in axarr[1,p].yaxis.get_major_ticks():
+            tick.label.set_fontsize(fs) 
+        
         #plot horizontal green line on model image, and steady state
         axarr[0,p].axhline(y=t, alpha=0.5, lw=2, color = 'g')
 
